## Immediate TODO

- [x] more agressive job killing
- [x] after job completes, show complete logs
- [ ] cleanup git functions
- [ ] cleanup git tags optional
- [ ] dependent jobs (a after b is done)
- [ ] nicer error messages on the cli instead of showing apierror
- [ ] better secrets management
- [ ] git branch mode
- [ ] multi node and auth with dht and dqlite
- [ ] documentation
- [ ] job execution isolation
